function y = bsscbspline(x, m)
%BSSCBSPLINE Central normalized B-Spline function.
%
% INPUTS:
%
%    x:
%        A scalar value, column vector, or matrix of values for which
%        the value of the B-spline of order m is desired.
%
%     m:
%        The bspline order. m >= 1.
%
% OUTPUTS:
%
%    y: 
%        Output values of the bspline evaluated at x. The shape will be
%        the same as the input shape.
%
% DESCRIPTION:
%
%     BSSCBSPLINE(X) returns the value(s) of the Central normalized
%     B-Spline of order M evaluated at values in X.
%
%     BSSCBSPLINE(X) > 0 for all X in the open interval (-M/2, M/2) and
%     zero elsewhere, so BSSCBSPLINE is a function having compact support
%     centered at zero. BSSCBSPLINE also integrates to one, i.e., it can be
%     thought of as a probability density function.
%

%
% Copyright 2014-2018 Biometrics Northwest LLC
%

%
% Created: 2014-11-25
% Author : Kevin R. Gehringer
%

y = bssbasisfun(  x + m/2, m );
